ltcp

package
v0.16.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 26, 2026 License: GPL-3.0 Imports: 6 Imported by: 0

Documentation

Overview

Package ltcp implements local TCP port forwarding.

Usage:

-listen ltcp://:LOCAL_PORT/TARGET_HOST:TARGET_PORT -forward ssh://user:pass@server:22

Listens on LOCAL_PORT locally and forwards each connection through the proxy chain to TARGET_HOST:TARGET_PORT on the remote side.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewLTCPServer

func NewLTCPServer(s string, p proxy.Proxy) (proxy.Server, error)

NewLTCPServer returns a new LTCP server.

Types

type LTCP

type LTCP struct {
	// contains filtered or unexported fields
}

LTCP is a local TCP port forwarder.

func (*LTCP) ListenAndServe

func (s *LTCP) ListenAndServe()

ListenAndServe listens on local addr and serves connections.

func (*LTCP) Serve

func (s *LTCP) Serve(c net.Conn)

Serve serves a connection by dialing the target through the proxy chain.

Jump to