ssh

package
v0.16.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 26, 2026 License: GPL-3.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewSSHDialer

func NewSSHDialer(s string, d proxy.Dialer) (proxy.Dialer, error)

NewSSHDialer returns a ssh proxy dialer.

Types

type SSH

type SSH struct {
	// contains filtered or unexported fields
}

SSH is a base ssh struct with persistent client and keepalive support.

func NewSSH

func NewSSH(s string, d proxy.Dialer, p proxy.Proxy) (*SSH, error)

NewSSH returns a ssh proxy.

func (*SSH) Addr

func (s *SSH) Addr() string

Addr returns forwarder's address.

func (*SSH) Dial

func (s *SSH) Dial(network, addr string) (net.Conn, error)

Dial connects to the address addr on the network net via the SSH tunnel. Uses persistent multiplexed SSH client for efficiency.

func (*SSH) DialUDP

func (s *SSH) DialUDP(network, addr string) (pc net.PacketConn, writeTo net.Addr, err error)

DialUDP connects to the given address via the proxy.

func (*SSH) Listen

func (s *SSH) Listen(network, addr string) (net.Listener, error)

Listen requests the remote SSH server to listen on the given address. Implements proxy.RemoteListener for rtcp support.

Jump to