Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type SSH ¶
type SSH struct {
// contains filtered or unexported fields
}
SSH is a base ssh struct with persistent client and keepalive support.
func (*SSH) Dial ¶
Dial connects to the address addr on the network net via the SSH tunnel. Uses persistent multiplexed SSH client for efficiency.
Click to show internal directories.
Click to hide internal directories.